"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    workload_id: str,
    lens_alias: str,
    question_id: str,
    milestone_number: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get the answer to a specific question in a workload review.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        question_id(str): The ID of the question.
        milestone_number(int, optional): The milestone number. A workload can have a maximum of 100 milestones. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.answer.get(
                ctx, workload_id=value, lens_alias=value, question_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.answer.get workload_id=value, lens_alias=value, question_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="get_answer",
        op_kwargs={
            "WorkloadId": workload_id,
            "LensAlias": lens_alias,
            "QuestionId": question_id,
            "MilestoneNumber": milestone_number,
        },
    )


async def list_all(
    hub,
    ctx,
    workload_id: str,
    lens_alias: str,
    pillar_id: str = None,
    milestone_number: int = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List of answers.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        pillar_id(str, optional): The ID used to identify a pillar, for example, security. A pillar is identified by its PillarReviewSummary$PillarId. Defaults to None.
        milestone_number(int, optional): The milestone number. A workload can have a maximum of 100 milestones. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.answer.list_all(
                ctx, workload_id=value, lens_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.answer.list_all workload_id=value, lens_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_answers",
        op_kwargs={
            "WorkloadId": workload_id,
            "LensAlias": lens_alias,
            "PillarId": pillar_id,
            "MilestoneNumber": milestone_number,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    workload_id: str,
    lens_alias: str,
    question_id: str,
    selected_choices: List = None,
    choice_updates: Dict = None,
    notes: str = None,
    is_applicable: bool = None,
    reason: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the answer to a specific question in a workload review.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        question_id(str): The ID of the question.
        selected_choices(List, optional): List of selected choice IDs in a question answer. The values entered replace the previously selected choices. Defaults to None.
        choice_updates(Dict, optional): A list of choices to update on a question in your workload. The String key corresponds to the choice ID to be updated. Defaults to None.
        notes(str, optional): The notes associated with the workload. Defaults to None.
        is_applicable(bool, optional): Defines whether this question is applicable to a lens review. Defaults to None.
        reason(str, optional): The reason why a question is not applicable to your workload. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.answer.update(
                ctx, workload_id=value, lens_alias=value, question_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.answer.update workload_id=value, lens_alias=value, question_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="update_answer",
        op_kwargs={
            "WorkloadId": workload_id,
            "LensAlias": lens_alias,
            "QuestionId": question_id,
            "SelectedChoices": selected_choices,
            "ChoiceUpdates": choice_updates,
            "Notes": notes,
            "IsApplicable": is_applicable,
            "Reason": reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This implementation of the GET action uses the accelerate subresource to return the Transfer Acceleration state of a bucket, which is either Enabled or Suspended. Amazon S3 Transfer Acceleration is a bucket-level feature that enables you to perform faster data transfers to and from Amazon S3. To use this operation, you must have permission to perform the s3:GetAccelerateConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to your Amazon S3 Resources in the Amazon S3 User Guide. You set the Transfer Acceleration state of an existing bucket to Enabled or Suspended by using the PutBucketAccelerateConfiguration operation.  A GET accelerate request does not return a state value for a bucket that has no transfer acceleration state. A bucket has no Transfer Acceleration state if a state has never been set on the bucket.  For more information about transfer acceleration, see Transfer Acceleration in the Amazon S3 User Guide.  Related Resources     PutBucketAccelerateConfiguration

    Args:
        bucket(str): The name of the bucket for which the accelerate configuration is retrieved.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.accelerate_configuration.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.accelerate_configuration.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_accelerate_configuration",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    accelerate_configuration: Dict,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the accelerate configuration of an existing bucket. Amazon S3 Transfer Acceleration is a bucket-level feature that enables you to perform faster data transfers to Amazon S3.  To use this operation, you must have permission to perform the s3:PutAccelerateConfiguration action. The bucket owner has this permission by default. The bucket owner can grant this permission to others. For more information about permissions, see Permissions Related to Bucket Subresource Operations and Managing Access Permissions to Your Amazon S3 Resources.  The Transfer Acceleration state of a bucket can be set to one of the following two values:    Enabled – Enables accelerated data transfers to the bucket.    Suspended – Disables accelerated data transfers to the bucket.   The GetBucketAccelerateConfiguration action returns the transfer acceleration state of a bucket. After setting the Transfer Acceleration state of a bucket to Enabled, it might take up to thirty minutes before the data transfer rates to the bucket increase.  The name of the bucket used for Transfer Acceleration must be DNS-compliant and must not contain periods (".").  For more information about transfer acceleration, see Transfer Acceleration. The following operations are related to PutBucketAccelerateConfiguration:    GetBucketAccelerateConfiguration     CreateBucket

    Args:
        bucket(str): The name of the bucket for which the accelerate configuration is set.
        accelerate_configuration(Dict): Container for setting the transfer acceleration state.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.accelerate_configuration.put(
                ctx, bucket=value, accelerate_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.accelerate_configuration.put bucket=value, accelerate_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_accelerate_configuration",
        op_kwargs={
            "Bucket": bucket,
            "AccelerateConfiguration": accelerate_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, recipe_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a recipe. A recipe contains three items:   An algorithm that trains a model.   Hyperparameters that govern the training.   Feature transformation information for modifying the input data before training.   Amazon Personalize provides a set of predefined recipes. You specify a recipe when you create a solution with the CreateSolution API. CreateSolution trains a model by using the algorithm in the specified recipe and a training dataset. The solution, when deployed as a campaign, can provide recommendations using the GetRecommendations API.

    Args:
        recipe_arn(str): The Amazon Resource Name (ARN) of the recipe to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.recipe.describe(ctx, recipe_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.recipe.describe recipe_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_recipe",
        op_kwargs={"recipeArn": recipe_arn},
    )


async def list_all(
    hub,
    ctx,
    recipe_provider: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of available recipes. The response provides the properties for each recipe, including the recipe's Amazon Resource Name (ARN).

    Args:
        recipe_provider(str, optional): The default is SERVICE. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListRecipes for getting the next set of recipes (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of recipes to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.recipe.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.recipe.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_recipes",
        op_kwargs={
            "recipeProvider": recipe_provider,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, parent_id: str, name: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an organizational unit (OU) within a root or parent OU. An OU is a container for accounts that enables you to organize your accounts to apply policies according to your business requirements. The number of levels deep that you can nest OUs is dependent upon the policy types enabled for that root. For service control policies, the limit is five. For more information about OUs, see Managing Organizational Units in the AWS Organizations User Guide.  If the request includes tags, then the requester must have the organizations:TagResource permission. This operation can be called only from the organization's management account.

    Args:
        parent_id(str): The unique identifier (ID) of the parent root or OU that you want to create the new OU in. The regex pattern for a parent ID string requires one of the following:    Root - A string that begins with "r-" followed by from 4 to 32 lowercase letters or digits.    Organizational unit (OU) - A string that begins with "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.  .
        name(str): The friendly name to assign to the new OU.
        tags(List, optional): A list of tags that you want to attach to the newly created OU. For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can't set it to null. For more information about tagging, see Tagging AWS Organizations resources in the AWS Organizations User Guide.  If any one of the tags is invalid or if you exceed the allowed number of tags for an OU, then the entire request fails and the OU is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organizational_unit.init.create(
                ctx, parent_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organizational_unit.init.create parent_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="create_organizational_unit",
        op_kwargs={"ParentId": parent_id, "Name": name, "Tags": tags},
    )


async def delete(hub, ctx, organizational_unit_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an organizational unit (OU) from a root or another OU. You must first remove all accounts and child OUs from the OU that you want to delete. This operation can be called only from the organization's management account.

    Args:
        organizational_unit_id(str): The unique identifier (ID) of the organizational unit that you want to delete. You can get the ID from the ListOrganizationalUnitsForParent operation. The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organizational_unit.init.delete(
                ctx, organizational_unit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organizational_unit.init.delete organizational_unit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="delete_organizational_unit",
        op_kwargs={"OrganizationalUnitId": organizational_unit_id},
    )


async def describe(hub, ctx, organizational_unit_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an organizational unit (OU). This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        organizational_unit_id(str): The unique identifier (ID) of the organizational unit that you want details about. You can get the ID from the ListOrganizationalUnitsForParent operation. The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organizational_unit.init.describe(
                ctx, organizational_unit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organizational_unit.init.describe organizational_unit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_organizational_unit",
        op_kwargs={"OrganizationalUnitId": organizational_unit_id},
    )


async def update(hub, ctx, organizational_unit_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Renames the specified organizational unit (OU). The ID and ARN don't change. The child OUs and accounts remain in place, and any attached policies of the OU remain attached. This operation can be called only from the organization's management account.

    Args:
        organizational_unit_id(str): The unique identifier (ID) of the OU that you want to rename. You can get the ID from the ListOrganizationalUnitsForParent operation. The regex pattern for an organizational unit ID string requires "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.
        name(str, optional): The new name that you want to assign to the OU. The regex pattern that is used to validate this parameter is a string of any of the characters in the ASCII character range. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.organizational_unit.init.update(
                ctx, organizational_unit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.organizational_unit.init.update organizational_unit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="update_organizational_unit",
        op_kwargs={"OrganizationalUnitId": organizational_unit_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str = None,
    lo_ra_wan: Dict = None,
    tags: List = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new service profile.

    Args:
        name(str, optional): The name of the new resource. Defaults to None.
        lo_ra_wan(Dict, optional): The service profile information to use to create the service profile. Defaults to None.
        tags(List, optional): The tags to attach to the new service profile. Tags are metadata that you can use to manage a resource. Defaults to None.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.service.profile.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.service.profile.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_service_profile",
        op_kwargs={
            "Name": name,
            "LoRaWAN": lo_ra_wan,
            "Tags": tags,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a service profile.

    Args:
        id_(str): The ID of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.service.profile.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.service.profile.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_service_profile",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a service profile.

    Args:
        id_(str): The ID of the resource to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.service.profile.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.service.profile.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_service_profile",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the service profiles registered to your AWS account.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.service.profile.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.service.profile.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_service_profiles",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, domain_name: str, deployed: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see Configuring Domain Endpoint Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain.
        deployed(bool, optional): Whether to retrieve the latest configuration (which might be in a Processing state) or the current, active configuration. Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.domain.endpoint_option.describe_all(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.domain.endpoint_option.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_domain_endpoint_options",
        op_kwargs={"DomainName": domain_name, "Deployed": deployed},
    )


async def update_multiple(
    hub, ctx, domain_name: str, domain_endpoint_options: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the domain's endpoint options, specifically whether all requests to the domain must arrive over HTTPS. For more information, see Configuring Domain Endpoint Options in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain.
        domain_endpoint_options(Dict): Whether to require that all requests to the domain arrive over HTTPS. We recommend Policy-Min-TLS-1-2-2019-07 for TLSSecurityPolicy. For compatibility with older clients, the default is Policy-Min-TLS-1-0-2019-07. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.domain.endpoint_option.update_multiple(
                ctx, domain_name=value, domain_endpoint_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.domain.endpoint_option.update_multiple domain_name=value, domain_endpoint_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="update_domain_endpoint_options",
        op_kwargs={
            "DomainName": domain_name,
            "DomainEndpointOptions": domain_endpoint_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, organization_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the default retention policy details for the specified organization.

    Args:
        organization_id(str): The organization ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.default_retention_policy.get(
                ctx, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.default_retention_policy.get organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="get_default_retention_policy",
        op_kwargs={"OrganizationId": organization_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def define(hub, ctx, domain_name: str, index_field: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Configures an IndexField for the search domain. Used to create new fields and modify existing ones. You must specify the name of the domain you are configuring and an index field configuration. The index field configuration specifies a unique name, the index field type, and the options you want to configure for the field. The options you can specify depend on the IndexFieldType. If the field exists, the new configuration replaces the old one. For more information, see Configuring Index Fields in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        index_field(Dict): The index field and field options you want to configure. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.index_field.define(
                ctx, domain_name=value, index_field=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.index_field.define domain_name=value, index_field=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="define_index_field",
        op_kwargs={"DomainName": domain_name, "IndexField": index_field},
    )


async def delete(hub, ctx, domain_name: str, index_field_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an IndexField from the search domain. For more information, see Configuring Index Fields in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        index_field_name(str): The name of the index field your want to remove from the domain's indexing options.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.index_field.delete(
                ctx, domain_name=value, index_field_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.index_field.delete domain_name=value, index_field_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="delete_index_field",
        op_kwargs={"DomainName": domain_name, "IndexFieldName": index_field_name},
    )


async def describe_all(
    hub, ctx, domain_name: str, field_names: List = None, deployed: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the index fields configured for the search domain. Can be limited to specific fields by name. By default, shows all fields and includes any pending changes to the configuration. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Getting Domain Information in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        field_names(List, optional): A list of the index fields you want to describe. If not specified, information is returned for all configured index fields. Defaults to None.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.index_field.describe_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.index_field.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_index_fields",
        op_kwargs={
            "DomainName": domain_name,
            "FieldNames": field_names,
            "Deployed": deployed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a version of a component from IoT Greengrass.  This operation deletes the component's recipe and artifacts. As a result, deployments that refer to this component version will fail. If you have deployments that use this component version, you can remove the component from the deployment or update the deployment to use a valid version.

    Args:
        arn(str): The ARN of the component version.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.init.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.init.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="delete_component",
        op_kwargs={"arn": arn},
    )


async def describe(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata for a version of a component.

    Args:
        arn(str): The ARN of the component version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.init.describe(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.init.describe arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="describe_component",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str, recipe_output_format: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the recipe for a version of a component. Core devices can call this operation to identify the artifacts and requirements to install a component.

    Args:
        recipe_output_format(str, optional): The format of the recipe. Defaults to None.
        arn(str): The ARN of the component version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.init.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.init.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="get_component",
        op_kwargs={"recipeOutputFormat": recipe_output_format, "arn": arn},
    )


async def list_all(
    hub, ctx, scope: str = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of component summaries. This list includes components that you have permission to view.

    Args:
        scope(str, optional): The scope of the components to list. Default: PRIVATE . Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per paginated request. Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.component.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.component.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="list_components",
        op_kwargs={"scope": scope, "maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of JobListEntry objects of the specified length. Each JobListEntry object contains a job's state, a job's ID, and a value that indicates whether the job is a job part, in the case of export jobs. Calling this API action in one of the US regions will return jobs from the list of all jobs associated with this account in all US regions.

    Args:
        max_results(int, optional): The number of JobListEntry objects to return. Defaults to None.
        next_token(str, optional): HTTP requests are stateless. To identify what object comes "next" in the list of JobListEntry objects, you have the option of specifying NextToken as the starting point for your returned list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="list_jobs",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, feature_transformation_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the given feature transformation.

    Args:
        feature_transformation_arn(str): The Amazon Resource Name (ARN) of the feature transformation to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.feature_transformation.describe(
                ctx, feature_transformation_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.feature_transformation.describe feature_transformation_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_feature_transformation",
        op_kwargs={"featureTransformationArn": feature_transformation_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_name: str, date: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an automatic snapshot of an instance or disk. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        resource_name(str): The name of the source instance or disk from which to delete the automatic snapshot.
        date(str): The date of the automatic snapshot to delete in YYYY-MM-DD format. Use the get auto snapshots operation to get the available automatic snapshots for a resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.auto_snapshot.delete(
                ctx, resource_name=value, date=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.auto_snapshot.delete resource_name=value, date=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_auto_snapshot",
        op_kwargs={"resourceName": resource_name, "date": date},
    )


async def get_all(hub, ctx, resource_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the available automatic snapshots for an instance or disk. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        resource_name(str): The name of the source instance or disk from which to get automatic snapshot information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.auto_snapshot.get_all(ctx, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.auto_snapshot.get_all resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_auto_snapshots",
        op_kwargs={"resourceName": resource_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_fpga_image_id: str,
    source_region: str,
    dry_run: bool = None,
    description: str = None,
    name: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified Amazon FPGA Image (AFI) to the current Region.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        source_fpga_image_id(str): The ID of the source AFI.
        description(str, optional): The description for the new AFI. Defaults to None.
        name(str, optional): The name for the new AFI. The default is the name of the source AFI. Defaults to None.
        source_region(str): The Region that contains the source AFI.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.init.copy(
                ctx, source_fpga_image_id=value, source_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.init.copy source_fpga_image_id=value, source_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="copy_fpga_image",
        op_kwargs={
            "DryRun": dry_run,
            "SourceFpgaImageId": source_fpga_image_id,
            "Description": description,
            "Name": name,
            "SourceRegion": source_region,
            "ClientToken": client_token,
        },
    )


async def create(
    hub,
    ctx,
    input_storage_location: Dict,
    dry_run: bool = None,
    logs_storage_location: Dict = None,
    description: str = None,
    name: str = None,
    client_token: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP). The create operation is asynchronous. To verify that the AFI is ready for use, check the output logs. An AFI contains the FPGA bitstream that is ready to download to an FPGA. You can securely deploy an AFI on multiple FPGA-accelerated instances. For more information, see the AWS FPGA Hardware Development Kit.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        input_storage_location(Dict): The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.
        logs_storage_location(Dict, optional): The location in Amazon S3 for the output logs. Defaults to None.
        description(str, optional): A description for the AFI. Defaults to None.
        name(str, optional): A name for the AFI. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the FPGA image during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.init.create(ctx, input_storage_location=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.init.create input_storage_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_fpga_image",
        op_kwargs={
            "DryRun": dry_run,
            "InputStorageLocation": input_storage_location,
            "LogsStorageLocation": logs_storage_location,
            "Description": description,
            "Name": name,
            "ClientToken": client_token,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(hub, ctx, fpga_image_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon FPGA Image (AFI).

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fpga_image_id(str): The ID of the AFI.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.init.delete(ctx, fpga_image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.init.delete fpga_image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_fpga_image",
        op_kwargs={"DryRun": dry_run, "FpgaImageId": fpga_image_id},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    fpga_image_ids: List = None,
    owners: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Amazon FPGA Images (AFIs) available to you. These include public AFIs, private AFIs that you own, and AFIs owned by other AWS accounts for which you have load permissions.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fpga_image_ids(List, optional): The AFI IDs. Defaults to None.
        owners(List, optional): Filters the AFI by owner. Specify an AWS account ID, self (owner is the sender of the request), or an AWS owner alias (valid values are amazon | aws-marketplace). Defaults to None.
        filters(List, optional): The filters.    create-time - The creation time of the AFI.    fpga-image-id - The FPGA image identifier (AFI ID).    fpga-image-global-id - The global FPGA image identifier (AGFI ID).    name - The name of the AFI.    owner-id - The AWS account ID of the AFI owner.    product-code - The product code.    shell-version - The version of the AWS Shell that was used to create the bitstream.    state - The state of the AFI (pending | failed | available | unavailable).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    update-time - The time of the most recent update.  . Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fpga_images",
        op_kwargs={
            "DryRun": dry_run,
            "FpgaImageIds": fpga_image_ids,
            "Owners": owners,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "data_set"


async def generate(
    hub,
    ctx,
    data_set_type: str,
    data_set_publication_date: str,
    role_name_arn: str,
    destination_s3_bucket_name: str,
    sns_topic_arn: str,
    destination_s3_prefix: str = None,
    customer_defined_values: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Given a data set type and data set publication date, asynchronously publishes the requested data set to the specified S3 bucket and notifies the specified SNS topic once the data is available. Returns a unique request identifier that can be used to correlate requests with notifications from the SNS topic. Data sets will be published in comma-separated values (CSV) format with the file name {data_set_type}_YYYY-MM-DD.csv. If a file with the same name already exists (e.g. if the same data set is requested twice), the original file will be overwritten by the new file. Requires a Role with an attached permissions policy providing Allow permissions for the following actions: s3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes, sns:Publish, iam:GetRolePolicy.

    Args:
        data_set_type(str): The desired data set type.    customer_subscriber_hourly_monthly_subscriptions From 2017-09-15 to present: Available daily by 24:00 UTC.   customer_subscriber_annual_subscriptions From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_usage_by_instance_type From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_fees From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_free_trial_conversions From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_new_instances From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_new_product_subscribers From 2017-09-15 to present: Available daily by 24:00 UTC.   daily_business_canceled_product_subscribers From 2017-09-15 to present: Available daily by 24:00 UTC.   monthly_revenue_billing_and_revenue_data From 2017-09-15 to present: Available monthly on the 15th day of the month by 24:00 UTC. Data includes metered transactions (e.g. hourly) from one month prior.   monthly_revenue_annual_subscriptions From 2017-09-15 to present: Available monthly on the 15th day of the month by 24:00 UTC. Data includes up-front software charges (e.g. annual) from one month prior.   monthly_revenue_field_demonstration_usage From 2018-03-15 to present: Available monthly on the 15th day of the month by 24:00 UTC.   monthly_revenue_flexible_payment_schedule From 2018-11-15 to present: Available monthly on the 15th day of the month by 24:00 UTC.   disbursed_amount_by_product From 2017-09-15 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_instance_hours From 2017-09-15 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_customer_geo From 2017-09-15 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_age_of_uncollected_funds From 2017-09-15 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_age_of_disbursed_funds From 2017-09-15 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_age_of_past_due_funds From 2018-04-07 to present: Available every 30 days by 24:00 UTC.   disbursed_amount_by_uncollected_funds_breakdown From 2019-10-04 to present: Available every 30 days by 24:00 UTC.   sales_compensation_billed_revenue From 2017-09-15 to present: Available monthly on the 15th day of the month by 24:00 UTC. Data includes metered transactions (e.g. hourly) from one month prior, and up-front software charges (e.g. annual) from one month prior.   us_sales_and_use_tax_records From 2017-09-15 to present: Available monthly on the 15th day of the month by 24:00 UTC.   disbursed_amount_by_product_with_uncollected_funds This data set is deprecated. Download related reports from AMMP instead!   customer_profile_by_industry This data set is deprecated. Download related reports from AMMP instead!   customer_profile_by_revenue This data set is deprecated. Download related reports from AMMP instead!   customer_profile_by_geography This data set is deprecated. Download related reports from AMMP instead!   .
        data_set_publication_date(str): The date a data set was published. For daily data sets, provide a date with day-level granularity for the desired day. For monthly data sets except those with prefix disbursed_amount, provide a date with month-level granularity for the desired month (the day value will be ignored). For data sets with prefix disbursed_amount, provide a date with day-level granularity for the desired day. For these data sets we will look backwards in time over the range of 31 days until the first data set is found (the latest one).
        role_name_arn(str): The Amazon Resource Name (ARN) of the Role with an attached permissions policy to interact with the provided AWS services.
        destination_s3_bucket_name(str): The name (friendly name, not ARN) of the destination S3 bucket.
        destination_s3_prefix(str, optional): (Optional) The desired S3 prefix for the published data set, similar to a directory path in standard file systems. For example, if given the bucket name "mybucket" and the prefix "myprefix/mydatasets", the output file "outputfile" would be published to "s3://mybucket/myprefix/mydatasets/outputfile". If the prefix directory structure does not exist, it will be created. If no prefix is provided, the data set will be published to the S3 bucket root. Defaults to None.
        sns_topic_arn(str): Amazon Resource Name (ARN) for the SNS Topic that will be notified when the data set has been published or if an error has occurred.
        customer_defined_values(Dict, optional): (Optional) Key-value pairs which will be returned, unmodified, in the Amazon SNS notification message and the data set metadata file. These key-value pairs can be used to correlated responses with tracking information from other systems. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplacecommerceanalytic.data_set_.generate(
                ctx,
                data_set_type=value,
                data_set_publication_date=value,
                role_name_arn=value,
                destination_s3_bucket_name=value,
                sns_topic_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplacecommerceanalytic.data_set.generate data_set_type=value, data_set_publication_date=value, role_name_arn=value, destination_s3_bucket_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplacecommerceanalytics",
        operation="generate_data_set",
        op_kwargs={
            "dataSetType": data_set_type,
            "dataSetPublicationDate": data_set_publication_date,
            "roleNameArn": role_name_arn,
            "destinationS3BucketName": destination_s3_bucket_name,
            "destinationS3Prefix": destination_s3_prefix,
            "snsTopicArn": sns_topic_arn,
            "customerDefinedValues": customer_defined_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, qualification_type_id: str, worker_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The GetQualificationScore operation returns the value of a Worker's Qualification for a given Qualification type.   To get a Worker's Qualification, you must know the Worker's ID. The Worker's ID is included in the assignment data returned by the ListAssignmentsForHIT operation.  Only the owner of a Qualification type can query the value of a Worker's Qualification of that type.

    Args:
        qualification_type_id(str): The ID of the QualificationType.
        worker_id(str): The ID of the Worker whose Qualification is being updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.score.get(
                ctx, qualification_type_id=value, worker_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.score.get qualification_type_id=value, worker_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="get_qualification_score",
        op_kwargs={"QualificationTypeId": qualification_type_id, "WorkerId": worker_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_arn: str, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a user's device.

    Args:
        fleet_arn(str): The ARN of the fleet.
        device_id(str): A unique identifier for a registered user's device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.device.init.describe(
                ctx, fleet_arn=value, device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.device.init.describe fleet_arn=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_device",
        op_kwargs={"FleetArn": fleet_arn, "DeviceId": device_id},
    )


async def list_all(
    hub, ctx, fleet_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of devices registered with the specified fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        next_token(str, optional): The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        max_results(int, optional): The maximum number of results to be included in the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.device.init.list_all(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.device.init.list_all fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="list_devices",
        op_kwargs={
            "FleetArn": fleet_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def send(
    hub,
    ctx,
    room_filters: List,
    content: Dict,
    client_request_token: str,
    time_to_live_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Triggers an asynchronous flow to send text, SSML, or audio announcements to rooms that are identified by a search or filter.

    Args:
        room_filters(List): The filters to use to send an announcement to a specified list of rooms. The supported filter keys are RoomName, ProfileName, RoomArn, and ProfileArn. To send to all rooms, specify an empty RoomFilters list.
        content(Dict): The announcement content. This can contain only one of the three possible announcement types (text, SSML or audio).
        time_to_live_in_seconds(int, optional): The time to live for an announcement. Default is 300. If delivery doesn't occur within this time, the announcement is not delivered. Defaults to None.
        client_request_token(str): The unique, user-specified identifier for the request that ensures idempotency.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.announcement.send(
                ctx, room_filters=value, content=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.announcement.send room_filters=value, content=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="send_announcement",
        op_kwargs={
            "RoomFilters": room_filters,
            "Content": content,
            "TimeToLiveInSeconds": time_to_live_in_seconds,
            "ClientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, config_rule_name: str, external_evaluation: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Add or updates the evaluations for process checks. This API checks if the rule is a process check when the name of the AWS Config rule is provided.

    Args:
        config_rule_name(str): The name of the AWS Config rule.
        external_evaluation(Dict): An ExternalEvaluation object that provides details about compliance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.external_evaluation.put(
                ctx, config_rule_name=value, external_evaluation=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.external_evaluation.put config_rule_name=value, external_evaluation=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_external_evaluation",
        op_kwargs={
            "ConfigRuleName": config_rule_name,
            "ExternalEvaluation": external_evaluation,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def authorize(hub, ctx, data_share_arn: str, consumer_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    From a data producer account, authorizes the sharing of a datashare with one or more consumer accounts. To authorize a datashare for a data consumer, the producer account must have the correct access privileges.

    Args:
        data_share_arn(str): The Amazon Resource Name (ARN) of the datashare that producers are to authorize sharing for.
        consumer_identifier(str): The identifier of the data consumer that is authorized to access the datashare. This identifier is an AWS account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.init.authorize(
                ctx, data_share_arn=value, consumer_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.init.authorize data_share_arn=value, consumer_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="authorize_data_share",
        op_kwargs={
            "DataShareArn": data_share_arn,
            "ConsumerIdentifier": consumer_identifier,
        },
    )


async def deauthorize(hub, ctx, data_share_arn: str, consumer_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    From the producer account, removes authorization from the specified datashare.

    Args:
        data_share_arn(str): The Amazon Resource Name (ARN) of the datashare to remove authorization from.
        consumer_identifier(str): The identifier of the data consumer that is to have authorization removed from the datashare. This identifier is an AWS account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.init.deauthorize(
                ctx, data_share_arn=value, consumer_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.init.deauthorize data_share_arn=value, consumer_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="deauthorize_data_share",
        op_kwargs={
            "DataShareArn": data_share_arn,
            "ConsumerIdentifier": consumer_identifier,
        },
    )


async def describe_all(
    hub, ctx, data_share_arn: str = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Shows the status of any inbound or outbound datashares available in the specified account.

    Args:
        data_share_arn(str, optional): The identifier of the datashare to describe details of. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. . Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeDataShares request exceed the value specified in MaxRecords, AWS returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_data_shares",
        op_kwargs={
            "DataShareArn": data_share_arn,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def reject(hub, ctx, data_share_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    From the consumer account, rejects the specified datashare.

    Args:
        data_share_arn(str): The Amazon Resource Name (ARN) of the datashare to reject.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.data_share.init.reject(ctx, data_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.data_share.init.reject data_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="reject_data_share",
        op_kwargs={"DataShareArn": data_share_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "entity_type"


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an entity type. You cannot delete an entity type that is included in an event type. When you delete an entity type, Amazon Fraud Detector permanently deletes that entity type and the data is no longer stored in Amazon Fraud Detector.

    Args:
        name(str): The name of the entity type to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.entity_type_.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.entity_type.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_entity_type",
        op_kwargs={"name": name},
    )


async def get_all(
    hub, ctx, name: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets all entity types or a specific entity type if a name is specified. This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEntityTypesResponse as part of your request. A null pagination token fetches the records from the beginning.

    Args:
        name(str, optional): The name. Defaults to None.
        next_token(str, optional): The next token for the subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of objects to return for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.entity_type_.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.entity_type.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_entity_types",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )


async def put(hub, ctx, name: str, description: str = None, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an entity type. An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account.

    Args:
        name(str): The name of the entity type.
        description(str, optional): The description. Defaults to None.
        tags(List, optional): A collection of key and value pairs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.entity_type_.put(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.entity_type.put name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_entity_type",
        op_kwargs={"name": name, "description": description, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_arn: str, tag_list: List) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Adds or overwrites one or more tags for the specified AWS CloudHSM resource. Each tag consists of a key and a value. Tag keys must be unique to each resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the AWS CloudHSM resource to tag.
        tag_list(List): One or more tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.tags.to_resource.add(
                ctx, resource_arn=value, tag_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.tags.to_resource.add resource_arn=value, tag_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagList": tag_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    provider_type: str,
    provider_endpoint: str,
    vpc_configuration: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a resource that represents the infrastructure where a third-party provider is installed. The host is used when you create connections to an installed third-party provider type, such as GitHub Enterprise Server. You create one host for all connections to that provider.  A host created through the CLI or the SDK is in `PENDING` status by default. You can make its status `AVAILABLE` by setting up the host in the console.

    Args:
        name(str): The name of the host to be created. The name must be unique in the calling AWS account.
        provider_type(str): The name of the installed provider to be associated with your connection. The host resource represents the infrastructure where your provider type is installed. The valid provider type is GitHub Enterprise Server.
        provider_endpoint(str): The endpoint of the infrastructure to be represented by the host after it is created.
        vpc_configuration(Dict, optional): The VPC configuration to be provisioned for the host. A VPC must be configured and the infrastructure to be represented by the host must already be connected to the VPC. Defaults to None.
        tags(List, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_connection.host.create(
                ctx, name=value, provider_type=value, provider_endpoint=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_connection.host.create name=value, provider_type=value, provider_endpoint=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-connections",
        operation="create_host",
        op_kwargs={
            "Name": name,
            "ProviderType": provider_type,
            "ProviderEndpoint": provider_endpoint,
            "VpcConfiguration": vpc_configuration,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, host_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    The host to be deleted. Before you delete a host, all connections associated to the host must be deleted.  A host cannot be deleted if it is in the VPC_CONFIG_INITIALIZING or VPC_CONFIG_DELETING state.

    Args:
        host_arn(str): The Amazon Resource Name (ARN) of the host to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_connection.host.delete(ctx, host_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_connection.host.delete host_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-connections",
        operation="delete_host",
        op_kwargs={"HostArn": host_arn},
    )


async def get(hub, ctx, host_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration.

    Args:
        host_arn(str): The Amazon Resource Name (ARN) of the requested host.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_connection.host.get(ctx, host_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_connection.host.get host_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-connections",
        operation="get_host",
        op_kwargs={"HostArn": host_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the hosts associated with your account.

    Args:
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token that was returned from the previous ListHosts call, which can be used to return the next set of hosts in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_connection.host.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_connection.host.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-connections",
        operation="list_hosts",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    host_arn: str,
    provider_endpoint: str = None,
    vpc_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specified host with the provided configurations.

    Args:
        host_arn(str): The Amazon Resource Name (ARN) of the host to be updated.
        provider_endpoint(str, optional): The URL or endpoint of the host to be updated. Defaults to None.
        vpc_configuration(Dict, optional): The VPC configuration of the host to be updated. A VPC must be configured and the infrastructure to be represented by the host must already be connected to the VPC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar_connection.host.update(ctx, host_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar_connection.host.update host_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar-connections",
        operation="update_host",
        op_kwargs={
            "HostArn": host_arn,
            "ProviderEndpoint": provider_endpoint,
            "VpcConfiguration": vpc_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    detector_model_name: str,
    detector_model_definition: Dict,
    role_arn: str,
    detector_model_description: str = None,
    key: str = None,
    tags: List = None,
    evaluation_method: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a detector model.

    Args:
        detector_model_name(str): The name of the detector model.
        detector_model_definition(Dict): Information that defines how the detectors operate.
        detector_model_description(str, optional): A brief description of the detector model. Defaults to None.
        key(str, optional): The input attribute key used to identify a device or system to create a detector (an instance of the detector model) and then to route each input received to the appropriate detector (instance). This parameter uses a JSON-path expression in the message payload of each input to specify the attribute-value pair that is used to identify the device associated with the input. Defaults to None.
        role_arn(str): The ARN of the role that grants permission to AWS IoT Events to perform its operations.
        tags(List, optional): Metadata that can be used to manage the detector model. Defaults to None.
        evaluation_method(str, optional): Information about the order in which events are evaluated and how actions are executed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.init.create(
                ctx, detector_model_name=value, detector_model_definition=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.init.create detector_model_name=value, detector_model_definition=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="create_detector_model",
        op_kwargs={
            "detectorModelName": detector_model_name,
            "detectorModelDefinition": detector_model_definition,
            "detectorModelDescription": detector_model_description,
            "key": key,
            "roleArn": role_arn,
            "tags": tags,
            "evaluationMethod": evaluation_method,
        },
    )


async def delete(hub, ctx, detector_model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a detector model. Any active instances of the detector model are also deleted.

    Args:
        detector_model_name(str): The name of the detector model to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.init.delete(
                ctx, detector_model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.init.delete detector_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="delete_detector_model",
        op_kwargs={"detectorModelName": detector_model_name},
    )


async def describe(
    hub, ctx, detector_model_name: str, detector_model_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a detector model. If the version parameter is not specified, information about the latest version is returned.

    Args:
        detector_model_name(str): The name of the detector model.
        detector_model_version(str, optional): The version of the detector model. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.init.describe(
                ctx, detector_model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.init.describe detector_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="describe_detector_model",
        op_kwargs={
            "detectorModelName": detector_model_name,
            "detectorModelVersion": detector_model_version,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the detector models you have created. Only the metadata associated with each detector model is returned.

    Args:
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="list_detector_models",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    detector_model_name: str,
    detector_model_definition: Dict,
    role_arn: str,
    detector_model_description: str = None,
    evaluation_method: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a detector model. Detectors (instances) spawned by the previous version are deleted and then re-created as new inputs arrive.

    Args:
        detector_model_name(str): The name of the detector model that is updated.
        detector_model_definition(Dict): Information that defines how a detector operates.
        detector_model_description(str, optional): A brief description of the detector model. Defaults to None.
        role_arn(str): The ARN of the role that grants permission to AWS IoT Events to perform its operations.
        evaluation_method(str, optional): Information about the order in which events are evaluated and how actions are executed. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.detector_model.init.update(
                ctx, detector_model_name=value, detector_model_definition=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.detector_model.init.update detector_model_name=value, detector_model_definition=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="update_detector_model",
        op_kwargs={
            "detectorModelName": detector_model_name,
            "detectorModelDefinition": detector_model_definition,
            "detectorModelDescription": detector_model_description,
            "roleArn": role_arn,
            "evaluationMethod": evaluation_method,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, instance_groups: List, job_flow_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more instance groups to a running cluster.

    Args:
        instance_groups(List): Instance groups to add.
        job_flow_id(str): Job flow in which to add the instance groups.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.instance.group.add(
                ctx, instance_groups=value, job_flow_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.instance.group.add instance_groups=value, job_flow_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="add_instance_groups",
        op_kwargs={"InstanceGroups": instance_groups, "JobFlowId": job_flow_id},
    )


async def list_all(hub, ctx, cluster_id: str, marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Provides all available details about the instance groups in a cluster.

    Args:
        cluster_id(str): The identifier of the cluster for which to list the instance groups.
        marker(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.instance.group.list_all(ctx, cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.instance.group.list_all cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_instance_groups",
        op_kwargs={"ClusterId": cluster_id, "Marker": marker},
    )


async def modify(
    hub, ctx, cluster_id: str = None, instance_groups: List = None
) -> None:
    r"""
    **Autogenerated function**

    ModifyInstanceGroups modifies the number of nodes and configuration settings of an instance group. The input parameters include the new target instance count for the group and the instance group ID. The call will either succeed or fail atomically.

    Args:
        cluster_id(str, optional): The ID of the cluster to which the instance group belongs. Defaults to None.
        instance_groups(List, optional): Instance groups to change. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.instance.group.modify(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.instance.group.modify
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="modify_instance_groups",
        op_kwargs={"ClusterId": cluster_id, "InstanceGroups": instance_groups},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, name: str, filters: Dict, group_by_attribute: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom insight in Security Hub. An insight is a consolidation of findings that relate to a security issue that requires attention or remediation. To group the related findings in the insight, use the GroupByAttribute.

    Args:
        name(str): The name of the custom insight to create.
        filters(Dict): One or more attributes used to filter the findings included in the insight. The insight only includes findings that match the criteria defined in the filters.
        group_by_attribute(str): The attribute used to group the findings for the insight. The grouping attribute identifies the type of item that the insight applies to. For example, if an insight is grouped by resource identifier, then the insight produces a list of resource identifiers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.insight.init.create(
                ctx, name=value, filters=value, group_by_attribute=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.insight.init.create name=value, filters=value, group_by_attribute=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="create_insight",
        op_kwargs={
            "Name": name,
            "Filters": filters,
            "GroupByAttribute": group_by_attribute,
        },
    )


async def delete(hub, ctx, insight_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the insight specified by the InsightArn.

    Args:
        insight_arn(str): The ARN of the insight to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.insight.init.delete(ctx, insight_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.insight.init.delete insight_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="delete_insight",
        op_kwargs={"InsightArn": insight_arn},
    )


async def get_all(
    hub, ctx, insight_arns: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists and describes insights for the specified insight ARNs.

    Args:
        insight_arns(List, optional): The ARNs of the insights to describe. If you do not provide any insight ARNs, then GetInsights returns all of your custom insights. It does not return any managed insights. Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the GetInsights operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.
        max_results(int, optional): The maximum number of items to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.insight.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.insight.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_insights",
        op_kwargs={
            "InsightArns": insight_arns,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    insight_arn: str,
    name: str = None,
    filters: Dict = None,
    group_by_attribute: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Security Hub insight identified by the specified insight ARN.

    Args:
        insight_arn(str): The ARN of the insight that you want to update.
        name(str, optional): The updated name for the insight. Defaults to None.
        filters(Dict, optional): The updated filters that define this insight. Defaults to None.
        group_by_attribute(str, optional): The updated GroupBy attribute that defines this insight. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.insight.init.update(ctx, insight_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.insight.init.update insight_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="update_insight",
        op_kwargs={
            "InsightArn": insight_arn,
            "Name": name,
            "Filters": filters,
            "GroupByAttribute": group_by_attribute,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def lookup(
    hub,
    ctx,
    lookup_attributes: List = None,
    start_time: str = None,
    end_time: str = None,
    event_category: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Looks up management events or CloudTrail Insights events that are captured by CloudTrail. You can look up events that occurred in a region within the last 90 days. Lookup supports the following attributes for management events:   AWS access key   Event ID   Event name   Event source   Read only   Resource name   Resource type   User name   Lookup supports the following attributes for Insights events:   Event ID   Event name   Event source   All attributes are optional. The default number of results returned is 50, with a maximum of 50 possible. The response includes a token that you can use to get the next page of results.  The rate of lookup requests is limited to two per second, per account, per region. If this limit is exceeded, a throttling error occurs.

    Args:
        lookup_attributes(List, optional): Contains a list of lookup attributes. Currently the list can contain only one item. Defaults to None.
        start_time(str, optional): Specifies that only events that occur after or at the specified time are returned. If the specified start time is after the specified end time, an error is returned. Defaults to None.
        end_time(str, optional): Specifies that only events that occur before or at the specified time are returned. If the specified end time is before the specified start time, an error is returned. Defaults to None.
        event_category(str, optional): Specifies the event category. If you do not specify an event category, events of the category are not returned in the response. For example, if you do not specify insight as the value of EventCategory, no Insights events are returned. Defaults to None.
        max_results(int, optional): The number of events to return. Possible values are 1 through 50. The default is 50. Defaults to None.
        next_token(str, optional): The token to use to get the next page of results after a previous API call. This token must be passed in with the same parameters that were specified in the the original call. For example, if the original call specified an AttributeKey of 'Username' with a value of 'root', the call with NextToken should include those same parameters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.event.init.lookup(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.event.init.lookup
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="lookup_events",
        op_kwargs={
            "LookupAttributes": lookup_attributes,
            "StartTime": start_time,
            "EndTime": end_time,
            "EventCategory": event_category,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    instance_id: str,
    type_name: str,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A list of inventory items returned by the request.

    Args:
        instance_id(str): The instance ID for which you want inventory information.
        type_name(str): The type of inventory item for which you want information.
        filters(List, optional): One or more filters. Use a filter to return a more specific list of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.entry.list_all(
                ctx, instance_id=value, type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.entry.list_all instance_id=value, type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_inventory_entries",
        op_kwargs={
            "InstanceId": instance_id,
            "TypeName": type_name,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, identities: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the custom MAIL FROM attributes for a list of identities (email addresses : domains). This operation is throttled at one request per second and can only get custom MAIL FROM attributes for up to 100 identities at a time.

    Args:
        identities(List): A list of one or more identities.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.mail_from_domain.attribute.get_all(
                ctx, identities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.mail_from_domain.attribute.get_all identities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="get_identity_mail_from_domain_attributes",
        op_kwargs={"Identities": identities},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, image_recipe_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets an image recipe policy.

    Args:
        image_recipe_arn(str): The Amazon Resource Name (ARN) of the image recipe whose policy you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.recipe.policy.get(
                ctx, image_recipe_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.recipe.policy.get image_recipe_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_image_recipe_policy",
        op_kwargs={"imageRecipeArn": image_recipe_arn},
    )


async def put(hub, ctx, image_recipe_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

     Applies a policy to an image recipe. We recommend that you call the RAM API CreateResourceShare to share resources. If you call the Image Builder API PutImageRecipePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy in order for the resource to be visible to all principals with whom the resource is shared.

    Args:
        image_recipe_arn(str): The Amazon Resource Name (ARN) of the image recipe that this policy should be applied to.
        policy(str): The policy to apply.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.recipe.policy.put(
                ctx, image_recipe_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.recipe.policy.put image_recipe_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="put_image_recipe_policy",
        op_kwargs={"imageRecipeArn": image_recipe_arn, "policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of RuleGroup objects that you are subscribed to.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more ByteMatchSetssubscribed rule groups than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of subscribed rule groups. For the second and subsequent ListSubscribedRuleGroupsRequest requests, specify the value of NextMarker from the previous response to get information about another batch of subscribed rule groups. Defaults to None.
        limit(int, optional): Specifies the number of subscribed rule groups that you want AWS WAF to return for this request. If you have more objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.subscribed_rule_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.subscribed_rule_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_subscribed_rule_groups",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the current Security Hub member account from the associated administrator account. This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.from_.administrator_account.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.from_.administrator_account.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="disassociate_from_administrator_account",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    global_network_id: str,
    device_id: str,
    connected_device_id: str,
    link_id: str = None,
    connected_link_id: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a connection between two devices. The devices can be a physical or virtual appliance that connects to a third-party appliance in a VPC, or a physical appliance that connects to another physical appliance in an on-premises network.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the first device in the connection.
        connected_device_id(str): The ID of the second device in the connection.
        link_id(str, optional): The ID of the link for the first device. Defaults to None.
        connected_link_id(str, optional): The ID of the link for the second device. Defaults to None.
        description(str, optional): A description of the connection. Length Constraints: Maximum length of 256 characters. Defaults to None.
        tags(List, optional): The tags to apply to the resource during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.connection.create(
                ctx, global_network_id=value, device_id=value, connected_device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.connection.create global_network_id=value, device_id=value, connected_device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="create_connection",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "ConnectedDeviceId": connected_device_id,
            "LinkId": link_id,
            "ConnectedLinkId": connected_link_id,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, global_network_id: str, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified connection in your global network.

    Args:
        global_network_id(str): The ID of the global network.
        connection_id(str): The ID of the connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.connection.delete(
                ctx, global_network_id=value, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.connection.delete global_network_id=value, connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="delete_connection",
        op_kwargs={"GlobalNetworkId": global_network_id, "ConnectionId": connection_id},
    )


async def get_all(
    hub,
    ctx,
    global_network_id: str,
    connection_ids: List = None,
    device_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more of your connections in a global network.

    Args:
        global_network_id(str): The ID of the global network.
        connection_ids(List, optional): One or more connection IDs. Defaults to None.
        device_id(str, optional): The ID of the device. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.connection.get_all(ctx, global_network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.connection.get_all global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="get_connections",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "ConnectionIds": connection_ids,
            "DeviceId": device_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    global_network_id: str,
    connection_id: str,
    link_id: str = None,
    connected_link_id: str = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the information for an existing connection. To remove information for any of the parameters, specify an empty string.

    Args:
        global_network_id(str): The ID of the global network.
        connection_id(str): The ID of the connection.
        link_id(str, optional): The ID of the link for the first device in the connection. Defaults to None.
        connected_link_id(str, optional): The ID of the link for the second device in the connection. Defaults to None.
        description(str, optional): A description of the connection. Length Constraints: Maximum length of 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.connection.update(
                ctx, global_network_id=value, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.connection.update global_network_id=value, connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="update_connection",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "ConnectionId": connection_id,
            "LinkId": link_id,
            "ConnectedLinkId": connected_link_id,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, domain_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and subject to change. Before calling this API, use CreateDomain or UpdateDomain to enable identity resolution: set Matching to true. GetMatches returns potentially matching profiles, based on the results of the latest run of a machine learning process.   Amazon Connect runs a batch process every Saturday at 12AM UTC to identify matching profiles. The results are returned up to seven days after the Saturday run.  Amazon Connect uses the following profile attributes to identify matches:   PhoneNumber   HomePhoneNumber   BusinessPhoneNumber   MobilePhoneNumber   EmailAddress   PersonalEmailAddress   BusinessEmailAddress   FullName   BusinessName

    Args:
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.match.get_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.match.get_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="get_matches",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "DomainName": domain_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def import_(
    hub, ctx, firewall_domain_list_id: str, operation: str, domain_file_url: str
) -> Dict:
    r"""
    **Autogenerated function**

    Imports domain names from a file into a domain list, for use in a DNS firewall rule group.  Each domain specification in your domain list must satisfy the following requirements:    It can optionally start with * (asterisk).   With the exception of the optional starting asterisk, it must only contain the following characters: A-Z, a-z, 0-9, - (hyphen).   It must be from 1-255 characters in length.

    Args:
        firewall_domain_list_id(str): The ID of the domain list that you want to modify with the import operation.
        operation(str): What you want DNS Firewall to do with the domains that are listed in the file. This must be set to REPLACE, which updates the domain list to exactly match the list in the file. .
        domain_file_url(str): The fully qualified URL or URI of the file stored in Amazon Simple Storage Service (Amazon S3) that contains the list of domains to import. The file must be in an S3 bucket that's in the same Region as your DNS Firewall. The file must be a text file and must contain a single domain per line.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.init.import(ctx, firewall_domain_list_id=value, operation=value, domain_file_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.init.import firewall_domain_list_id=value, operation=value, domain_file_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="import_firewall_domains",
        op_kwargs={
            "FirewallDomainListId": firewall_domain_list_id,
            "Operation": operation,
            "DomainFileUrl": domain_file_url,
        },
    )


async def list_all(
    hub,
    ctx,
    firewall_domain_list_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the domains that you have defined for the specified firewall domain list.  A single call might return only a partial list of the domains. For information, see MaxResults.

    Args:
        firewall_domain_list_id(str): The ID of the domain list whose domains you want to retrieve. .
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.init.list_all(ctx, firewall_domain_list_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.init.list_all firewall_domain_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_domains",
        op_kwargs={
            "FirewallDomainListId": firewall_domain_list_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update_multiple(
    hub, ctx, firewall_domain_list_id: str, operation: str, domains: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the firewall domain list from an array of domain specifications.

    Args:
        firewall_domain_list_id(str): The ID of the domain list whose domains you want to update. .
        operation(str): What you want DNS Firewall to do with the domains that you are providing:     ADD - Add the domains to the ones that are already in the domain list.     REMOVE - Search the domain list for the domains and remove them from the list.    REPLACE - Update the domain list to exactly match the list that you are providing.   .
        domains(List): A list of domains to use in the update operation. Each domain specification in your domain list must satisfy the following requirements:    It can optionally start with * (asterisk).   With the exception of the optional starting asterisk, it must only contain the following characters: A-Z, a-z, 0-9, - (hyphen).   It must be from 1-255 characters in length.   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.init.update_multiple(ctx, firewall_domain_list_id=value, operation=value, domains=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.init.update_multiple firewall_domain_list_id=value, operation=value, domains=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_firewall_domains",
        op_kwargs={
            "FirewallDomainListId": firewall_domain_list_id,
            "Operation": operation,
            "Domains": domains,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, alarm_model_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the versions of an alarm model. The operation returns only the metadata associated with each alarm model version.

    Args:
        alarm_model_name(str): The name of the alarm model.
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent.alarm_model.version.list_all(
                ctx, alarm_model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent.alarm_model.version.list_all alarm_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents",
        operation="list_alarm_model_versions",
        op_kwargs={
            "alarmModelName": alarm_model_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, aws_account_id: str, dashboard_id: str, version_number: int
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the published version of a dashboard.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the dashboard that you're updating.
        dashboard_id(str): The ID for the dashboard.
        version_number(int): The version number of the dashboard.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.dashboard.published_version.update(
                ctx, aws_account_id=value, dashboard_id=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.dashboard.published_version.update aws_account_id=value, dashboard_id=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_dashboard_published_version",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DashboardId": dashboard_id,
            "VersionNumber": version_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     Returns the number of open reactive insights, the number of open proactive insights, and the number of metrics analyzed in your AWS account. Use these numbers to gauge the health of operations in your AWS account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.account.health.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.account.health.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_account_health",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, attachment_id: str, connection_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides a pre-signed URL for download of a completed attachment. This is an asynchronous API for use with active contacts.

    Args:
        attachment_id(str): A unique identifier for the attachment.
        connection_token(str): The authentication token associated with the participant's connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.attachment.init.get(
                ctx, attachment_id=value, connection_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.attachment.init.get attachment_id=value, connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="get_attachment",
        op_kwargs={"AttachmentId": attachment_id, "ConnectionToken": connection_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    group_name: str,
    aws_account_id: str,
    namespace: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon QuickSight group. The permissions resource is arn:aws:quicksight:us-east-1:<relevant-aws-account-id>:group/default/<group-name> . The response is a group object.

    Args:
        group_name(str): A name for the group that you want to create.
        description(str, optional): A description for the group that you want to create. Defaults to None.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.init.create(
                ctx, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.init.create group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_group",
        op_kwargs={
            "GroupName": group_name,
            "Description": description,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )


async def delete(
    hub, ctx, group_name: str, aws_account_id: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a user group from Amazon QuickSight.

    Args:
        group_name(str): The name of the group that you want to delete.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.init.delete(
                ctx, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.init.delete group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_group",
        op_kwargs={
            "GroupName": group_name,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )


async def describe(
    hub, ctx, group_name: str, aws_account_id: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an Amazon QuickSight group's description and Amazon Resource Name (ARN).

    Args:
        group_name(str): The name of the group that you want to describe.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.init.describe(
                ctx, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.init.describe group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_group",
        op_kwargs={
            "GroupName": group_name,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )


async def list_all(
    hub,
    ctx,
    aws_account_id: str,
    namespace: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all user groups in Amazon QuickSight.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        next_token(str, optional): A pagination token that can be used in a subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.init.list_all(
                ctx, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.init.list_all aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_groups",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Namespace": namespace,
        },
    )


async def update(
    hub,
    ctx,
    group_name: str,
    aws_account_id: str,
    namespace: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes a group description.

    Args:
        group_name(str): The name of the group that you want to update.
        description(str, optional): The description for the group that you want to update. Defaults to None.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.init.update(
                ctx, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.init.update group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_group",
        op_kwargs={
            "GroupName": group_name,
            "Description": description,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    integration_type: str,
    connection_id: str = None,
    connection_type: str = None,
    content_handling_strategy: str = None,
    credentials_arn: str = None,
    description: str = None,
    integration_method: str = None,
    integration_subtype: str = None,
    integration_uri: str = None,
    passthrough_behavior: str = None,
    payload_format_version: str = None,
    request_parameters: Dict = None,
    request_templates: Dict = None,
    response_parameters: Dict = None,
    template_selection_expression: str = None,
    timeout_in_millis: int = None,
    tls_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Integration.

    Args:
        api_id(str): The API identifier.
        connection_id(str, optional): The ID of the VPC link for a private integration. Supported only for HTTP APIs. Defaults to None.
        connection_type(str, optional): The type of the network connection to the integration endpoint. Specify INTERNET for connections through the public routable internet or VPC_LINK for private connections between API Gateway and resources in a VPC. The default value is INTERNET. Defaults to None.
        content_handling_strategy(str, optional): Supported only for WebSocket APIs. Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors: CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a response payload from a binary blob to a Base64-encoded string. If this property is not defined, the response payload will be passed through from the integration response to the route response or method response without modification. Defaults to None.
        credentials_arn(str, optional): Specifies the credentials required for the integration, if any. For AWS integrations, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify the string arn:aws:iam::*:user/*. To use resource-based permissions on supported AWS services, specify null. Defaults to None.
        description(str, optional): The description of the integration. Defaults to None.
        integration_method(str, optional): Specifies the integration's HTTP method type. Defaults to None.
        integration_subtype(str, optional): Supported only for HTTP API AWS_PROXY integrations. Specifies the AWS service action to invoke. To learn more, see Integration subtype reference. Defaults to None.
        integration_type(str): The integration type of an integration. One of the following: AWS: for integrating the route or method request with an AWS service action, including the Lambda function-invoking action. With the Lambda function-invoking action, this is referred to as the Lambda custom integration. With any other AWS service action, this is known as AWS integration. Supported only for WebSocket APIs. AWS_PROXY: for integrating the route or method request with a Lambda function or other AWS service action. This integration is also referred to as a Lambda proxy integration. HTTP: for integrating the route or method request with an HTTP endpoint. This integration is also referred to as the HTTP custom integration. Supported only for WebSocket APIs. HTTP_PROXY: for integrating the route or method request with an HTTP endpoint, with the client request passed through as-is. This is also referred to as HTTP proxy integration. For HTTP API private integrations, use an HTTP_PROXY integration. MOCK: for integrating the route or method request with API Gateway as a "loopback" endpoint without invoking any backend. Supported only for WebSocket APIs.
        integration_uri(str, optional): For a Lambda integration, specify the URI of a Lambda function. For an HTTP integration, specify a fully-qualified URL. For an HTTP API private integration, specify the ARN of an Application Load Balancer listener, Network Load Balancer listener, or AWS Cloud Map service. If you specify the ARN of an AWS Cloud Map service, API Gateway uses DiscoverInstances to identify resources. You can use query parameters to target specific resources. To learn more, see DiscoverInstances. For private integrations, all resources must be owned by the same AWS account. Defaults to None.
        passthrough_behavior(str, optional): Specifies the pass-through behavior for incoming requests based on the Content-Type header in the request, and the available mapping templates specified as the requestTemplates property on the Integration resource. There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and NEVER. Supported only for WebSocket APIs. WHEN_NO_MATCH passes the request body for unmapped content types through to the integration backend without transformation. NEVER rejects unmapped content types with an HTTP 415 Unsupported Media Type response. WHEN_NO_TEMPLATES allows pass-through when the integration has no content types mapped to templates. However, if there is at least one content type defined, unmapped content types will be rejected with the same HTTP 415 Unsupported Media Type response. Defaults to None.
        payload_format_version(str, optional): Specifies the format of the payload sent to an integration. Required for HTTP APIs. Defaults to None.
        request_parameters(Dict, optional): For WebSocket APIs, a key-value map specifying request parameters that are passed from the method request to the backend. The key is an integration request parameter name and the associated value is a method request parameter value or static value that must be enclosed within single quotes and pre-encoded as required by the backend. The method request parameter value must match the pattern of method.request.{location}.{name}
               , where
                  {location}
                is querystring, path, or header; and
                  {name}
                must be a valid and unique method request parameter name. For HTTP API integrations with a specified integrationSubtype, request parameters are a key-value map specifying parameters that are passed to AWS_PROXY integrations. You can provide static values, or map request data, stage variables, or context variables that are evaluated at runtime. To learn more, see Working with AWS service integrations for HTTP APIs. For HTTP API integrations without a specified integrationSubtype request parameters are a key-value map specifying how to transform HTTP requests before sending them to the backend. The key should follow the pattern <action>:<header|querystring|path>.<location> where action can be append, overwrite or remove. For values, you can provide static values, or map request data, stage variables, or context variables that are evaluated at runtime. To learn more, see Transforming API requests and responses. Defaults to None.
        request_templates(Dict, optional): Represents a map of Velocity templates that are applied on the request payload based on the value of the Content-Type header sent by the client. The content type value is the key in this map, and the template (as a String) is the value. Supported only for WebSocket APIs. Defaults to None.
        response_parameters(Dict, optional): Supported only for HTTP APIs. You use response parameters to transform the HTTP response from a backend integration before returning the response to clients. Specify a key-value map from a selection key to response parameters. The selection key must be a valid HTTP status code within the range of 200-599. Response parameters are a key-value map. The key must match pattern <action>:<header>.<location> or overwrite.statuscode. The action can be append, overwrite or remove. The value can be a static value, or map to response data, stage variables, or context variables that are evaluated at runtime. To learn more, see Transforming API requests and responses. Defaults to None.
        template_selection_expression(str, optional): The template selection expression for the integration. Defaults to None.
        timeout_in_millis(int, optional): Custom timeout between 50 and 29,000 milliseconds for WebSocket APIs and between 50 and 30,000 milliseconds for HTTP APIs. The default timeout is 29 seconds for WebSocket APIs and 30 seconds for HTTP APIs. Defaults to None.
        tls_config(Dict, optional): The TLS configuration for a private integration. If you specify a TLS configuration, private integration traffic uses the HTTPS protocol. Supported only for HTTP APIs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.init.create(
                ctx, api_id=value, integration_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.init.create api_id=value, integration_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_integration",
        op_kwargs={
            "ApiId": api_id,
            "ConnectionId": connection_id,
            "ConnectionType": connection_type,
            "ContentHandlingStrategy": content_handling_strategy,
            "CredentialsArn": credentials_arn,
            "Description": description,
            "IntegrationMethod": integration_method,
            "IntegrationSubtype": integration_subtype,
            "IntegrationType": integration_type,
            "IntegrationUri": integration_uri,
            "PassthroughBehavior": passthrough_behavior,
            "PayloadFormatVersion": payload_format_version,
            "RequestParameters": request_parameters,
            "RequestTemplates": request_templates,
            "ResponseParameters": response_parameters,
            "TemplateSelectionExpression": template_selection_expression,
            "TimeoutInMillis": timeout_in_millis,
            "TlsConfig": tls_config,
        },
    )


async def delete(hub, ctx, api_id: str, integration_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Integration.

    Args:
        api_id(str): The API identifier.
        integration_id(str): The integration ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.init.delete(
                ctx, api_id=value, integration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.init.delete api_id=value, integration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_integration",
        op_kwargs={"ApiId": api_id, "IntegrationId": integration_id},
    )


async def get(hub, ctx, api_id: str, integration_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an Integration.

    Args:
        api_id(str): The API identifier.
        integration_id(str): The integration ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.init.get(
                ctx, api_id=value, integration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.init.get api_id=value, integration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_integration",
        op_kwargs={"ApiId": api_id, "IntegrationId": integration_id},
    )


async def get_all(
    hub, ctx, api_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the Integrations for an API.

    Args:
        api_id(str): The API identifier.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.init.get_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.init.get_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_integrations",
        op_kwargs={"ApiId": api_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    api_id: str,
    integration_id: str,
    connection_id: str = None,
    connection_type: str = None,
    content_handling_strategy: str = None,
    credentials_arn: str = None,
    description: str = None,
    integration_method: str = None,
    integration_subtype: str = None,
    integration_type: str = None,
    integration_uri: str = None,
    passthrough_behavior: str = None,
    payload_format_version: str = None,
    request_parameters: Dict = None,
    request_templates: Dict = None,
    response_parameters: Dict = None,
    template_selection_expression: str = None,
    timeout_in_millis: int = None,
    tls_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Integration.

    Args:
        api_id(str): The API identifier.
        connection_id(str, optional): The ID of the VPC link for a private integration. Supported only for HTTP APIs. Defaults to None.
        connection_type(str, optional): The type of the network connection to the integration endpoint. Specify INTERNET for connections through the public routable internet or VPC_LINK for private connections between API Gateway and resources in a VPC. The default value is INTERNET. Defaults to None.
        content_handling_strategy(str, optional): Supported only for WebSocket APIs. Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors: CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a response payload from a binary blob to a Base64-encoded string. If this property is not defined, the response payload will be passed through from the integration response to the route response or method response without modification. Defaults to None.
        credentials_arn(str, optional): Specifies the credentials required for the integration, if any. For AWS integrations, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify the string arn:aws:iam::*:user/*. To use resource-based permissions on supported AWS services, specify null. Defaults to None.
        description(str, optional): The description of the integration. Defaults to None.
        integration_id(str): The integration ID.
        integration_method(str, optional): Specifies the integration's HTTP method type. Defaults to None.
        integration_subtype(str, optional): Supported only for HTTP API AWS_PROXY integrations. Specifies the AWS service action to invoke. To learn more, see Integration subtype reference. Defaults to None.
        integration_type(str, optional): The integration type of an integration. One of the following: AWS: for integrating the route or method request with an AWS service action, including the Lambda function-invoking action. With the Lambda function-invoking action, this is referred to as the Lambda custom integration. With any other AWS service action, this is known as AWS integration. Supported only for WebSocket APIs. AWS_PROXY: for integrating the route or method request with a Lambda function or other AWS service action. This integration is also referred to as a Lambda proxy integration. HTTP: for integrating the route or method request with an HTTP endpoint. This integration is also referred to as the HTTP custom integration. Supported only for WebSocket APIs. HTTP_PROXY: for integrating the route or method request with an HTTP endpoint, with the client request passed through as-is. This is also referred to as HTTP proxy integration. For HTTP API private integrations, use an HTTP_PROXY integration. MOCK: for integrating the route or method request with API Gateway as a "loopback" endpoint without invoking any backend. Supported only for WebSocket APIs. Defaults to None.
        integration_uri(str, optional): For a Lambda integration, specify the URI of a Lambda function. For an HTTP integration, specify a fully-qualified URL. For an HTTP API private integration, specify the ARN of an Application Load Balancer listener, Network Load Balancer listener, or AWS Cloud Map service. If you specify the ARN of an AWS Cloud Map service, API Gateway uses DiscoverInstances to identify resources. You can use query parameters to target specific resources. To learn more, see DiscoverInstances. For private integrations, all resources must be owned by the same AWS account. Defaults to None.
        passthrough_behavior(str, optional): Specifies the pass-through behavior for incoming requests based on the Content-Type header in the request, and the available mapping templates specified as the requestTemplates property on the Integration resource. There are three valid values: WHEN_NO_MATCH, WHEN_NO_TEMPLATES, and NEVER. Supported only for WebSocket APIs. WHEN_NO_MATCH passes the request body for unmapped content types through to the integration backend without transformation. NEVER rejects unmapped content types with an HTTP 415 Unsupported Media Type response. WHEN_NO_TEMPLATES allows pass-through when the integration has no content types mapped to templates. However, if there is at least one content type defined, unmapped content types will be rejected with the same HTTP 415 Unsupported Media Type response. Defaults to None.
        payload_format_version(str, optional): Specifies the format of the payload sent to an integration. Required for HTTP APIs. Defaults to None.
        request_parameters(Dict, optional): For WebSocket APIs, a key-value map specifying request parameters that are passed from the method request to the backend. The key is an integration request parameter name and the associated value is a method request parameter value or static value that must be enclosed within single quotes and pre-encoded as required by the backend. The method request parameter value must match the pattern of method.request.{location}.{name}
          , where
            {location}
           is querystring, path, or header; and
            {name}
           must be a valid and unique method request parameter name. For HTTP API integrations with a specified integrationSubtype, request parameters are a key-value map specifying parameters that are passed to AWS_PROXY integrations. You can provide static values, or map request data, stage variables, or context variables that are evaluated at runtime. To learn more, see Working with AWS service integrations for HTTP APIs. For HTTP API integrations, without a specified integrationSubtype request parameters are a key-value map specifying how to transform HTTP requests before sending them to the backend. The key should follow the pattern <action>:<header|querystring|path>.<location> where action can be append, overwrite or remove. For values, you can provide static values, or map request data, stage variables, or context variables that are evaluated at runtime. To learn more, see Transforming API requests and responses. Defaults to None.
        request_templates(Dict, optional): Represents a map of Velocity templates that are applied on the request payload based on the value of the Content-Type header sent by the client. The content type value is the key in this map, and the template (as a String) is the value. Supported only for WebSocket APIs. Defaults to None.
        response_parameters(Dict, optional): Supported only for HTTP APIs. You use response parameters to transform the HTTP response from a backend integration before returning the response to clients. Specify a key-value map from a selection key to response parameters. The selection key must be a valid HTTP status code within the range of 200-599. Response parameters are a key-value map. The key must match pattern <action>:<header>.<location> or overwrite.statuscode. The action can be append, overwrite or remove. The value can be a static value, or map to response data, stage variables, or context variables that are evaluated at runtime. To learn more, see Transforming API requests and responses. Defaults to None.
        template_selection_expression(str, optional): The template selection expression for the integration. Defaults to None.
        timeout_in_millis(int, optional): Custom timeout between 50 and 29,000 milliseconds for WebSocket APIs and between 50 and 30,000 milliseconds for HTTP APIs. The default timeout is 29 seconds for WebSocket APIs and 30 seconds for HTTP APIs. Defaults to None.
        tls_config(Dict, optional): The TLS configuration for a private integration. If you specify a TLS configuration, private integration traffic uses the HTTPS protocol. Supported only for HTTP APIs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.init.update(
                ctx, api_id=value, integration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.init.update api_id=value, integration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_integration",
        op_kwargs={
            "ApiId": api_id,
            "ConnectionId": connection_id,
            "ConnectionType": connection_type,
            "ContentHandlingStrategy": content_handling_strategy,
            "CredentialsArn": credentials_arn,
            "Description": description,
            "IntegrationId": integration_id,
            "IntegrationMethod": integration_method,
            "IntegrationSubtype": integration_subtype,
            "IntegrationType": integration_type,
            "IntegrationUri": integration_uri,
            "PassthroughBehavior": passthrough_behavior,
            "PayloadFormatVersion": payload_format_version,
            "RequestParameters": request_parameters,
            "RequestTemplates": request_templates,
            "ResponseParameters": response_parameters,
            "TemplateSelectionExpression": template_selection_expression,
            "TimeoutInMillis": timeout_in_millis,
            "TlsConfig": tls_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all OpsItem events in the current Region and account. You can limit the results to events associated with specific OpsItems by specifying a filter.

    Args:
        filters(List, optional): One or more OpsItem filters. Use a filter to return a more specific list of results. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. . Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.ops.item.event.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.ops.item.event.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_ops_item_events",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "set"


async def list_all(
    hub, ctx, resource_group_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the log pattern sets in the specific application.

    Args:
        resource_group_name(str): The name of the resource group.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.log_pattern.set_.list_all(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.log_pattern.set.list_all resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_log_pattern_sets",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    assignment_duration_in_seconds: int,
    reward: str,
    title: str,
    description: str,
    auto_approval_delay_in_seconds: int = None,
    keywords: str = None,
    qualification_requirements: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The CreateHITType operation creates a new HIT type. This operation allows you to define a standard set of HIT properties to use when creating HITs. If you register a HIT type with values that match an existing HIT type, the HIT type ID of the existing type will be returned.

    Args:
        auto_approval_delay_in_seconds(int, optional):  The number of seconds after an assignment for the HIT has been submitted, after which the assignment is considered Approved automatically unless the Requester explicitly rejects it. . Defaults to None.
        assignment_duration_in_seconds(int):  The amount of time, in seconds, that a Worker has to complete the HIT after accepting it. If a Worker does not complete the assignment within the specified duration, the assignment is considered abandoned. If the HIT is still active (that is, its lifetime has not elapsed), the assignment becomes available for other users to find and accept. .
        reward(str):  The amount of money the Requester will pay a Worker for successfully completing the HIT. .
        title(str):  The title of the HIT. A title should be short and descriptive about the kind of task the HIT contains. On the Amazon Mechanical Turk web site, the HIT title appears in search results, and everywhere the HIT is mentioned. .
        keywords(str, optional):  One or more words or phrases that describe the HIT, separated by commas. These words are used in searches to find HITs. . Defaults to None.
        description(str):  A general description of the HIT. A description includes detailed information about the kind of task the HIT contains. On the Amazon Mechanical Turk web site, the HIT description appears in the expanded view of search results, and in the HIT and assignment screens. A good description gives the user enough information to evaluate the HIT before accepting it. .
        qualification_requirements(List, optional):  Conditions that a Worker's Qualifications must meet in order to accept the HIT. A HIT can have between zero and ten Qualification requirements. All requirements must be met in order for a Worker to accept the HIT. Additionally, other actions can be restricted using the ActionsGuarded field on each QualificationRequirement structure. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.type_.init.create(
                ctx,
                assignment_duration_in_seconds=value,
                reward=value,
                title=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.type_.init.create assignment_duration_in_seconds=value, reward=value, title=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_hit_type",
        op_kwargs={
            "AutoApprovalDelayInSeconds": auto_approval_delay_in_seconds,
            "AssignmentDurationInSeconds": assignment_duration_in_seconds,
            "Reward": reward,
            "Title": title,
            "Keywords": keywords,
            "Description": description,
            "QualificationRequirements": qualification_requirements,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def remove(hub, ctx, subscription_name: str, source_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a source identifier from an existing Amazon DocumentDB event notification subscription.

    Args:
        subscription_name(str): The name of the Amazon DocumentDB event notification subscription that you want to remove a source identifier from.
        source_identifier(str):  The source identifier to be removed from the subscription, such as the instance identifier for an instance, or the name of a security group. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.source_identifier.from_subscription.remove(
                ctx, subscription_name=value, source_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.source_identifier.from_subscription.remove subscription_name=value, source_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="remove_source_identifier_from_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SourceIdentifier": source_identifier,
        },
    )
